@@ -6,11 +6,13 @@
 """Provide L5 behavioral RTLIR type check pass."""
 
 from pymtl3.passes.rtlir.errors import PyMTLTypeError
+from pymtl3.passes.rtlir.rtype import RTLIRDataType as rdt
 from pymtl3.passes.rtlir.rtype import RTLIRType as rt
 
 from .BehavioralRTLIRTypeCheckL4Pass import (
     BehavioralRTLIRTypeCheckL4Pass,
     BehavioralRTLIRTypeCheckVisitorL4,
+    BehavioralRTLIRTypeEnforcerL4,
 )
 
 
@@ -20,14 +22,8 @@ class BehavioralRTLIRTypeCheckL5Pass( BehavioralRTLIRTypeCheckL4Pass ):
 
 class BehavioralRTLIRTypeCheckVisitorL5( BehavioralRTLIRTypeCheckVisitorL4 ):
 
-  def visit_Index( s, node ):
-    """Type check the index node."""
-    if isinstance( node.value.Type, rt.Array ) and \
-       isinstance( node.value.Type.get_sub_type(), rt.Component ):
-      node.Type = node.value.Type.get_next_dim_type()
-
-    else:
-      super().visit_Index( node )
+  def get_enforce_visitor( s ):
+    return BehavioralRTLIRTypeEnforcerL5
 
   def visit_Attribute( s, node ):
     """Type check an attribute.
@@ -46,5 +42,27 @@ class BehavioralRTLIRTypeCheckVisitorL5( BehavioralRTLIRTypeCheckVisitorL4 ):
         raise PyMTLTypeError( s.blk, node.ast,
           f'{node.attr} is not a port of {node.value.Type.get_name()} subcomponent!' )
       node.Type = prop
+      if isinstance(node.Type, rt.Const) and isinstance(node.Type.get_dtype(), rdt.Vector):
+        node._is_explicit = node.Type.get_dtype().is_explicit()
+      else:
+        node._is_explicit = True
     else:
       super().visit_Attribute( node )
+
+  def visit_Index( s, node ):
+    """Type check the index node."""
+    if isinstance( node.value.Type, rt.Array ) and \
+       isinstance( node.value.Type.get_sub_type(), rt.Component ):
+      node.Type = node.value.Type.get_next_dim_type()
+      node._is_explicit = True
+      s._handle_index_extension( node, node.value, node.idx, 'index' )
+
+    else:
+      super().visit_Index( node )
+
+#-------------------------------------------------------------------------
+# Enforce types for all terms whose types are inferred (implicit)
+#-------------------------------------------------------------------------
+
+class BehavioralRTLIRTypeEnforcerL5( BehavioralRTLIRTypeEnforcerL4 ):
+  pass
